%written by Alain Schlaepfer (2010)
%computes reference cycle for set of series (see Pagan, Harding (2004))
%input is matrix of turning points of each individual series
%additional input: 
%weights: vector of weights for each series (used to weight impact of each
%series differently)
%method: 1: median
%        2: weighted mean
%        3: min

function [refpeaks, reftroughs, s]=refcycle(tpoints, weights, method)
 
[dp dt]=distance(tpoints);
if method==2;
    weightsP=ones(size(dp,1),1)*weights';
    weightsT=weightsP;
    weightsP(isnan(dp)==1)=NaN;
    weightsT(isnan(dp)==1)=NaN;
    wPsum1=nansum(weightsP,2);
    wTsum1=nansum(weightsT,2);
    wPsum=ones(size(wPsum1,1), size(weights,1));
    wTsum=ones(size(wTsum1,1), size(weights,1));
    for i=1:size(weights,1);
        wPsum(:,i)=wPsum(:,i).*wPsum1;
        wTsum(:,i)=wTsum(:,i).*wTsum1;
    end;
    weightsP=weightsP./wPsum;
    weightsT=weightsT./wTsum;
    dp=dp.*weightsP;
    dt=dt.*weightsT;
end;
if method==1;
    mp=(nanmedian(dp'))';
    mt=(nanmedian(dt'))';
elseif method==2;
    mp=(nanmean(dp'))';
    mt=(nanmean(dt'))';
elseif method==3;
    mp=(nanmin(dp'))';
    mt=(nanmin(dt'))';
end;
q1p=(quantile(dp',.25))';
q2p=(quantile(dp',.75))';
q1t=(quantile(dt',.25))';
q2t=(quantile(dt',.75))';
q3p=(quantile(dp',.10))';
q4p=(quantile(dp',.90))';
q3t=(quantile(dt',.10))';
q4t=(quantile(dt',.90))';

[rp, rt]=refdate(mp, mt, q1p, q2p, q3p, q4p, q1t, q2t, q3t, q4t);

%make sure refpeaks alternate
[xx, rp1]=alter2(rt,rp,mp);
%make sure reftroughs alternate
[xx, rt1]=alter2(rp1,rt,mt);

%eliminate cycles that are too short
% adjust series such that 'peaks' are high
mcom=mt;
for i=1:rows(rp1);
    mcom(rp1(i,1),1)=mp(rp1(i,1),1);
end

%eliminate cycles that are too short
[rp2, rt2]=refenf1p(rp1, rt1, mcom);
%make sure refpeaks alternate
[xx, rp3]=alter2(rt2,rp2,mp);
%make sure reftroughs alternate
[xx, rt3]=alter2(rp3,rt2,mt);
% rp5=rp3;
% rt5=rt3;

%eliminate phases that are too short
[rp4, rt4]=enfve_dh(rp3, rt3, mcom);
%eliminate phases that are too short
[rp4, rt4]=enfve_dh(rp4, rt4, mcom);

%make sure refpeaks alternate
[xx, rp5]=alter2(rt4,rp4,mp);
%make sure reftroughs alternate
[xx, rt5]=alter2(rp5,rt4,mt);

%make sure refpeaks alternate
[xx, rp5]=alter2(rt5,rp5,mp);
%make sure reftroughs alternate
[xx, rt5]=alter2(rp5,rt5,mt);

refpeaks=zeros(rows(tpoints),1);
reftroughs=refpeaks;

% Print "Rows bcp5=" Rows(bcp5) "Rows bct5=" Rows(bct5);
%A: if not ismiss(bcp5);
%if isnan(bcp5);
if (rows(rp5)==0);
    disp('missing value encountered in peaks');
else
    i=1;
    while i<=rows(rp5);
        refpeaks(rp5(i))=1;
        i=i+1;
    end;
end;


%A: if not ismiss(bct5);
%if isnan(bct5);
if (rows(rt5)==0);
     disp('missing value encountered in troughs');
else
    i=1;
    while i<=rows(rt5);
        reftroughs(rt5(i))=1;
        i=i+1;
    end;
end;
s=states(rp5,rt5,rows(tpoints));
end