%Alain Schlaepfer (2010)
%computes average amplitude of reference cycle for a region
%i.e. average drop of change of real gdp across countries within a 
%region using the regional reference cycle
%INPUTS USED:
%1. reference cycle of each region as 'regionname' 'ref' (=output from
%region.m)
%2. regbase.m for the country-list of each region
%3. for each country, a mat-file named 'countryname', containing a matrix
%named 'countryname' with gdp data in first column and IP data in third
%column

%Output: File amplall, matrix 'ampall' contains for each region: 
%average amplitude of booms overall
%average amplitude of recession overall

clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                     ADJUST CONTROL VARIABLES

%load definition of regions
%set regions, see regbase.m for definitions
x=3;
[region1, region2, region3, region4, region5,names]=regbase(x);

%choose sample over which to compute: smp=0: whole sample, smp=1: up to
%specified date, smp=2: after specified date;
smp=0;
%specify date (2010q1-specdate), e.g. specdate=37=>2000q4; irrelevant if
%smp=0;
specdate=57;
%choose method of after sample selection. afterselect=0: only include
%phases starting after specified date, afterselect=1: all phases ending
%after specified date; irrelevant if smp=0 or smp=1;
afterselect=1;

%IPuse=0: use GDP only
%IPuse=1: use IP if no data on GDP available
%IPuse=2: use IP only
IPuse=1;

%choose name of output file
savefile  = 'amplafter1995IP2';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


ampall=[];
for j=1:size(names,2);
    ampbr=[];
    amprr=[];
    %check if region defined
    check=['region' num2str(j)];
    if size(eval(check),1)==0;
        ampbr=[NaN];
        amprr=[NaN];
    else
    %countries in region
    iregc=eval(check);
    %load refcycle of region    
    ireg=[char(names(j)) 'ref'];
    load(ireg);
    regcycle=rcycle(:,end);
    
    %loop over countries
    for i=1:size(iregc,1);
        ampbc=[];
        amprc=[];
        %load country data
        icon=[char(iregc(i))];
        load(icon)
        %extract gdp
        eval(['data =' icon ';']);
        gdp=data(:,1);
        %if no data on gdp available, try IP
        if IPuse==1;
            if sum(isnan(gdp))==size(gdp,1);
                gdp=data(:,3);
            end;
        end;
        %or use IP always
        if IPuse==2;
            gdp=data(:,3);            
        end;
        %use only regcycle where data available
        if size(regcycle,1)>size(gdp,1);
            rcyc=regcycle((end-size(gdp,1)+1):end,:);
        else
            gdp=gdp((end-size(regcycle,1)+1):end,:);
            rcyc=regcycle;
        end;
        time=(1:1:size(gdp,1))';
        peaks=selif(time, rcyc==1);
        troughs=selif(time, rcyc==-1);
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %selection of sample to evaluate
        if smp==1;
            peaks=peaks(peaks<=(size(gdp,1)-specdate));
            troughs=troughs(troughs<=(size(gdp,1)-specdate));
        end;
        if smp==2;
            if afterselect==0;
                peaks=peaks(peaks>(size(gdp,1)-specdate));
                troughs=troughs(troughs>(size(gdp,1)-specdate));
            else
                p1=peaks(peaks<=(size(gdp,1)-specdate));
                t1=troughs(troughs<=(size(gdp,1)-specdate));
                p1=max([p1; 0]);
                t1=max([t1; 0]);
                late=max(p1,t1);
                peaks=peaks(peaks>=late);
                troughs=troughs(troughs>=late);
            end;
        end;
        
        %check if phase exist
        if size(peaks,1)==0 || size(troughs,1)==0;
            ampbc=[NaN];
            amprc=[NaN];
        else
            %if peak first
            if peaks(1)<troughs(1);
                for r=1:size(troughs);
                    camp=(gdp(troughs(r))-gdp(peaks(r)))/gdp(peaks(r));
                    amprc=[amprc; camp];
                end;
                if size(peaks,1)==1
                    ampbc=[NaN];
                else
                    for b=2:size(peaks);
                        camp=(gdp(peaks(b))-gdp(troughs(b-1)))/gdp(troughs(b-1));
                        ampbc=[ampbc; camp];
                    end;
                end;
            else
                %trough first
                for b=1:size(peaks);
                    camp=(gdp(peaks(b))-gdp(troughs(b)))/gdp(troughs(b));
                    ampbc=[ampbc; camp];
                end;
                if size(troughs,1)==1
                    amprc=[NaN];
                else
                    for r=2:size(troughs);
                        camp=(gdp(troughs(r))-gdp(peaks(r-1)))/gdp(peaks(r-1));
                        amprc=[amprc; camp];
                    end;
                end
            end;
        end;
        %average amplitude for country
        ampbc=nanmean(ampbc);
        amprc=nanmean(amprc);
        ampbr=[ampbr ampbc];
        amprr=[amprr amprc];
        end;
    end;
    %average amplitude of region
    ampbr=nanmean(ampbr);
    amprr=nanmean(amprr);
    ampall=[ampall [ampbr;amprr]];
end;


save(savefile, 'ampall','names');        
            