%Alain Schlaepfer (2010)
%computes average duration of booms and recession for each region
%Needs refcycle output regions.m for regional reference cycle as input)

%Output: File, matrix 'avdur' contains for each country: 
%average duration of booms overall
%average duration of recession overall
%average duration of booms up to splitdate
%average duration of recession up to splitdate
%average duration of booms after splitdate (including only phases beginning after splitdate) 
%average duration of recession after splitdate
%average duration of booms up to splitdate
%average duration of recession up to splitdate
%average duration of booms after splitdate (including all phases ending
%after splitdate)
%average duration of recession after splitdate

clear all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%adjust control variables
%names of regions to be used
countries={'europebig';'europerest'; 'middleeast'; 'northafrica'; 'all'};
%countries={'euro';'noneuro'};
%date to split sample (2010q1-splitdate), eq. 2000q1/2001q1 = 36
splitdate=36;

%choose name of output file
savefile  = 'durationregions2000';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
avdur=[];
for i=1:rows(countries);
    icon=[char(countries(i)),'ref'];
    load (icon);
    %extract reference cycle of region
    refindic=rcycle(:,end);
    indic=selif(refindic,isnan(refindic)==0);
    [tpdall, ptdall]=avduration(indic);
    %after splitdate
    if size(refindic,1)>splitdate;
        indicafter=refindic(end-splitdate:end,:);
        indicafter=selif(indicafter,isnan(indicafter)==0);
    else
        indicafter=indic;
    end;
    %alternative: av. duration of phases ending after splitdate
    %extract last phase start date before chosen date
    if size(refindic,1)>splitdate;
        check=0;
        i=0;
        while check==0;
            i=i+1;
            if size(refindic,1)<(splitdate+1)
                check=1;
            else
                check=refindic(end-splitdate-i,:);
            end;
        end;
        indicafter2=refindic(end-splitdate-(i):end,:);
        indicafter2=indicafter2(isnan(indicafter2)==0);
        indicup2=refindic(1:end-splitdate-i,:);
        indicup2=indicup2(isnan(indicup2)==0);
    else
        indicafter2=indic;
    end;
    %up to splitdate
    if size(refindic,1)>(splitdate+1);
        indicup=refindic(1:end-(splitdate+1),:);
        indicup=selif(indicup,isnan(indicup)==0);
    else
        indicup=NaN;
    end;
    %compute average durations
    [tpdup, ptdup]=avduration(indicup);
    [tpdafter, ptdafter]=avduration(indicafter);
    [tpdup2, ptdup2]=avduration(indicup2);
    [tpdafter2, ptdafter2]=avduration(indicafter2);
    idur=[tpdall; ptdall;tpdup; ptdup; tpdafter; ptdafter; tpdup2; ptdup2; tpdafter2; ptdafter2];
    avdur=[avdur idur];
end;

save(savefile, 'avdur', 'countries');