% Gauss original: Camacho, Perez-Quiros (2008)
%   www.um.es/econometria/Maximo

% This Matlab file: Alain Schlaepfer (2010): alain.schlaepfer@upf.edu
% Computes cycle with BBQ for each series in
% file, plus overall reference cycle (as in Pagan, Harding (2004)), saves
% turning points of series and refcycle in file 'countryname'TP.mat

%INPUT needed:
%1. A file 'countryname'.mat, where country data is saved
%in a matrix 'countryname'
%order of series in this excercise is: real gdp, unemployment, IP, real
%sales, real income
%NOTE: the second series is reversed when dating such that a peak
%corresponds to low level of unemployment. If this is not desired, comment
%out lines 129-133
%2. Calls the functions finddates.m and refcycle.m


clear all
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++
%            ADJUST CONTROL SPECIFICATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%choose country
country='algeria';

%Alain: Controls for computation of reference cycle:

ref2=0;
%if ref2=1: refcycle only for perdiods with at least 2 variables avialable
method=2;
%method used to compute reference cycle, 1:median distance, 2: weighted mean
%distance, 3: min distance
weights=[0.3;0.25;0.2;0.15;0.1];
%weights used to compute ref cycle, only used if methods=2, mean
%Note: weights automatically adjusted such that sum=1 each period

%number of series to include (must be in the first n columns of the data
%matrix
nseries=5;

% controls from original gauss code:
k_peak=2;
% Tells code to look 2 quarters ahead when determining a peak
k_trough=2;
% Tells code to look 2 quarters ahead when determining a trough
l_peak=0;
% You can ignore these just set to zero 
l_trough=0;
% You can ignore these just set to zero 
a_peak=[];
a_trough=[];
grafico=0;
% grafico=0 to skip graphs 
summary=0;
%A: =1 for summary statistics

global BB_like icensor minycle print_censor minphase;
BB_like=0;
icensor=1;
%minimum duration of cycle
minycle=5;
print_censor=1;
%minimum duration of phase
minphase=2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%                Loading variables
load (country);
% Quarterly series 
datal=eval(country);
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++
%         Computing the recessionary indicators
% 
tpoints=[];
data=datal;
lseries=rows(data);

for i=1:nseries;

xl=data(:,i);

yl=selif(xl,isnan(xl)==0);

if rows(yl)==0;
else    

%start the dating function
[peaks,troughs,s]=findates(@ets_bbq,@cts_bbq,yl,k_peak,k_trough,l_peak,l_trough,a_peak,a_trough);
nber=1-(s+1)/2;

% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%                       Graphs
% 
if grafico==1;
    figure(i);
    bar(nber, 'c')
    h1 = gca;
    h2 = axes('Position',get(h1,'Position'));
    plot(yl,'LineWidth',2)
    set(h2,'YAxisLocation','right','Color','none','XTickLabel',[])
    set(h2,'XLim',get(h1,'XLim'),'Layer','top')
end;



% +++++++++++++++++++++++++++++++++++++++++++++++++++++++
%                     Output results

%A: compute summary statistics
if summary==1;
    t=seqa(1,1,rows(yl));
    peaks1=selif(t,(peaks==1));
    troughs1=selif(t,(troughs==1));
    [d]=durations(s,peaks1, troughs1);
    [p_t_stats,t_p_stats,p_t_long,t_p_long]=summary_stats(peaks1,troughs1,yl,d);
end;

%create turning point series
indica=peaks-troughs;
indic=zeros(lseries,1);
end;
ncount=1;
%extend turning point series with NaN
%such that all have same length in the end
for j=1:lseries;
    if isnan(xl(j,1))==0;
        indic(j,1)=indica(ncount,1);
        ncount=ncount+1;
    else
        indic(j,1)=NaN;
    end;
end;    

%switch peaks/troughs for unemployment
if i==2;
    indic=-indic;
end;
tpoints=[tpoints indic];
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%reference cycle dating
%reduce to time with at least 2 series of data if ref2==!
addl=0;
if ref2==1;
    tpointsred=selif(tpoints,sum(isnan(tpoints),2)<nseries-1);
    check=sum(isnan(tpoints(lseries,:)),2);
    %check for missing values at end of the series
    while check>=(nseries-1);
        addl=addl+1;
        check=sum(isnan(tpoints(lseries-addl,:)),2);
    end;
else
    tpointsred=tpoints;
end;

%compute reference cycle turning points
[refpeaks, reftroughs, refs]=refcycle(tpointsred, weights, method);
refindic=refpeaks-reftroughs;
for j=1:size(tpointsred,1);
     if isnan(tpointsred(j,:))==1;
         refindic(j)=NaN;
     end;
end;
   
tpoints1=[tpointsred refindic];
%add NaN at the end if nessecairy
if addl>0;
    add=tpoints(lseries+1-addl:lseries,:);
    add2=ones(addl,1)*NaN;
    add=[add add2];
    tpoints1=[tpoints1; add];
end;
tpoints=tpoints1;
refs(isnan(refindic)==1)=NaN;

%save turning points
savefile  = [country,'TP'];
save(savefile,'tpoints', 'refindic', 'refs');