%Alain Schlaepfer (2011)
%computes bilateral investment index for countries i and j:
%btindex=(invij+invji)/[totassetsi+totliabi+totassetsj+totliabj]
%if investment of i in j is not available, the denominator is computed
%without assets and liabilities of i

%INPUT used:
%financedata.mat, with matrizes: bilatPortfolio (bilateral investment) and
%BIS1

%OUTPUT generated:
%ouputfile with: bilateral investment index, plus labels indicating the countries

clear all
load('financedata');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       ADJUST CONTROL VARIABLES
%list countries (order must be the same as in BIS1
countries={'Cyprus';'France';'Greece';'Italy';'Jordan';'Portugal';'Spain';'Tunisia';'Turkey'};

%vector select, indicating the position of each country in the
%bilatPortfolio
select=[3;5;6;8;9;13;15;16;17];

%choose name of output file
savefile  = 'bil_finance';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n=size(countries,1);
bil=ones(n*(n-1)/2,1);
count=1;
for i=1:(size(BIS1)-1);
    for j=i+1:size(BIS1);
        %extract invest from i to j
        si=select(i);
        sj=select(j);
        invij=bilatPortfolio(sj,si);
        %extract invest from j to i
        invji=bilatPortfolio(si,sj);
        %extract assets and leverage of i and j (2009)
        ai=BIS1(i,7);
        aj=BIS1(j,7);
        li=BIS1(i,8);
        lj=BIS1(j,8);
        
        %set assets and leverage of i to zero if invij is NaN;
        ai=ai*(1-isnan(invij));
        li=li*(1-isnan(invij));
        %same for j
        aj=aj*(1-isnan(invji));
        lj=lj*(1-isnan(invji));
        
        %compute bilateral investment index
        bil(count,1)=nansum(invij+invji)/(ai+aj+li+lj);
        count=count+1;
    end;
end;
labels=[];
for i=1:size(countries,1)-1;
    for j=i+1:size(countries,1);
        label=[countries(i) countries(j)];
        labels=[labels; label];
    end;
end;

%save refcycle
save(savefile, 'bil', 'labels');