%Alain Schlaepfer (2010)
%computes bilateral concordence index for list of countries/regions
%Needs refcycle output from bbq2008.m as input (plus regions.m for regions
%input)

%Output: 
%'conc' contains for each country pairwise concordance index overall 
%'concup' contains for each country pairwise concordance index up to 2000 
%'concafter' contains for each country pairwise concordance index after
%2000 
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                      SET CONTROL VARIABLES
%list countries or regions to be analysed
countries={'algeria';'croatia';'cyprus'; 'egypt'; 'france'; 'greece'; 'israel'; 'italy'; 'jordan'; 'lebanon';...
    'macedonia'; 'malta'; 'morocco'; 'portugal';'serbia'; 'slovenia'; 'spain'; 'tunisia'; 'turkey'};% countries=sort(countries);
%countries={'europebig';'europerest'; 'middleeast'; 'northafrica'};
%countries={'euro';'noneuro'}
ifreg=0;
%set =1 if regions are analyzed, =0 if individual countries

%choose date where to split the sample, date of splitting is
%(lastdate-splitdate), e.g. (2010q1-36)=2001q1
splitdate=36;

savefile  = 'concall52mean';
%set name of output file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
exmin=500;

if ifreg==0;
    for i=1:rows(countries);
        icon=[char(countries(i)),'TP'];
        iref=[char(countries(i)),'refs'];
        load (icon);
        eval([iref ' =refs;']);
    end;
else
    for i=1:rows(countries);
        icon=[char(countries(i)),'ref'];
        iref=[char(countries(i)),'refs'];
        load (icon);
        rcycle=rcycle(:,end);
        refs=phase(rcycle);
        eval([iref ' =refs;']);
    end;
end;


conc=ones((rows(countries)*(rows(countries)-1)/2),1)*10;
concup=ones((rows(countries)*(rows(countries)-1)/2),1)*10;
concafter=ones((rows(countries)*(rows(countries)-1)/2),1)*10;
count=1;
names=[];

for i=1:(rows(countries)-1);
    iref=[char(countries(i)),'refs'];
    s1=eval(iref);
    n1=size(s1,1);
    %country name
    iname=countries(i);
    for j=i+1:rows(countries)
        jref=[char(countries(j)),'refs'];
        s2=eval(jref);
        n2=size(s2,1);
        n=min(n1,n2);
        %cut to same length
        su1=s1(1+n1-n:end,:);
        s2=s2(1+n2-n:end,:);
        s=[su1 s2];
        %after 2000
        safter=s(end-splitdate:end,:);
        %up to 2000
        sup=s(1:end-splitdate-1,:);
        %remove missing values
        s=selif(s,(sum(isnan(s),2)==0));
        safter=selif(safter,(sum(isnan(safter),2)==0));
        sup=selif(sup,(sum(isnan(sup),2)==0));
        [iconc, o]=concordence(s);
        [iconcafter, o]=concordence(safter);
        [iconcup, o]=concordence(sup);
        conc(count)=iconc;
        concafter(count)=iconcafter;
        concup(count)=iconcup;
        jname=countries(j);
        name=[iname jname];
        names=[names;name];
        %move up on position
        count=count+1;
    end;
end;


%save refcycle
save(savefile, 'conc', 'concup', 'concafter', 'names');