%Alain Schlaepfer (2011)
%Combutes simple correlations, regressions and rank correlations between
%trade and concordence

%INPUT used:
%1. Outputfile from regconcordence
%2. Outputfile from trade_pattern

%NOTE: countries need to have the same order in both files, and need to
%have the same date to split the sample (if interested in sub-sample
%analysis)

%OUTPUT saved:
%simple correlations: corrall, corrup, corrafter
%regresion statistics: statsall, statsup, statsafter
%Spearman rank coefficient: rhoall, rhoup, rhoafter
%Pearson rank coefficient: rall, rup, rafter
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    ADJUST CONTROL VARIABLES

%load bilateral concordence file
load('concall52mean')

%load bilateral trade file
load('bilateral_trade')

%set select=1 if only a subset of bilateral indices should be analyzed
select=1;

%indicate position of bilateral indices to be extracted (only relevant if
%select=1)
sub=[53;57;65;69;86;90;122;124;129;134];%morocco, tunisia and major euro

%choose name of output file
savefile  = 'trade_concordence_corr';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if select==1;
    %extract desired subsample
    extract=zeros(size(conc));
    for i=1:size(sub,1);
        extract(sub(i))=1;
    end;
    conc=conc(extract==1);
    trb=trb(extract==1);
    concup=concup(extract==1);
    trbup=trbup(extract==1);
    concafter=concafter(extract==1);
    trbafter=trbafter(extract==1);
end;

%make sure data available
checkall=zeros(size(conc));
checkup=checkall;
checkafter=checkup;
checkall(isnan(conc)==1)=1;
checkall(isnan(trb)==1)=1;
checkup(isnan(concup)==1)=1;
checkup(isnan(trbup)==1)=1;
checkafter(isnan(concafter)==1)=1;
checkafter(isnan(trbafter)==1)=1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%simple correlations
corrall=corr(conc(checkall==0),trb(checkall==0));
corrup=corr(concup(checkup==0),trbup(checkup==0));
corrafter=corr(concafter(checkafter==0), trbafter(checkafter==0));

% clear checkall checkup checkafter
% 
% 
% const=ones(size(conc));
% [beta,ci]=regress(conc(checkall==0),[const(checkall==0) trb(checkall==0)]);
% [betaup,ciup]=regress(concup(checkup==0),[const(checkup==0) trbup(checkup==0)]);
% [betaafter,ciafter]=regress(concafter(checkafter==0),[const(checkafter==0) trbafter(checkafter==0)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%regression statistics
y=conc(checkall==0);
X=trb(checkall==0);
yup=concup(checkup==0);
Xup=trbup(checkup==0);
yafter=concafter(checkafter==0);
Xafter=trbafter(checkafter==0);
statsall=regstats(y,X);
statsup=regstats(yup,Xup);
statsafter=regstats(yafter,Xafter);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%rank correlation
rtall=rankt(trb(checkall==0),'desc');
rtup=rankt(trbup(checkup==0),'desc');
rtafter=rankt(trbafter(checkafter==0),'desc');
rcall=rankt(conc(checkall==0),'desc');
rcup=rankt(concup(checkup==0),'desc');
rcafter=rankt(concafter(checkafter==0),'desc');

%compute spearman rank coefficient
n=size(rtall,1);
dist=rtall-rcall;
dsq=dist'*dist;
rhoall=1-6*dsq/(n*(n^2-1));

n=size(rtup,1);
dist=rtup-rcup;
dsq=dist'*dist;
rhoup=1-6*dsq/(n*(n^2-1));

n=size(rtafter,1);
dist=rtafter-rcafter;
dsq=dist'*dist;
rhoafter=1-6*dsq/(n*(n^2-1));

%pearson rank coefficient
X=rtall-mean(rtall);
Y=rcall-mean(rcall);
rall=X'*Y/((X'*X)*(Y'*Y))^(1/2);

X=rtup-mean(rtup);
Y=rcup-mean(rcup);
rup=X'*Y/((X'*X)*(Y'*Y))^(1/2);

X=rtafter-mean(rtafter);
Y=rcafter-mean(rcafter);
rafter=X'*Y/((X'*X)*(Y'*Y))^(1/2);

save(savefile, 'corrall', 'corrup', 'corrafter', 'statsall', 'statsup',...
    'statsafter', 'rhoall', 'rhoup', 'rhoafter', 'rall', 'rup', 'rafter');