%Alain Schlaepfer (2011)
%computes bilateral trade index for countries i and j:
%btindex=[(expij+impji)/2+(expji+impij)/2]/[totexpi+totimpi+totexpj+totimpj]

%INPUT used:
%tradefiles.mat, with matrizes: 'countryname'imp and 'countryname'exp

%OUTPUT generated:
%ouputfile with: bilateral trade index over whole sample and splitted
%sample, plus labels indicating the countries
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                       ADJUST CONTROL VARIABLES
%list countries
countries={'algeria'; 'croatia'; 'egypt'; 'france'; 'greece'; 'israel'; 'italy'; 'jordan'; 'lebanon';...
    'macedonia'; 'malta'; 'morocco'; 'portugal'; 'slovenia'; 'spain'; 'tunisia'; 'turkey'};
%list country belongs to which row in the data tables (same order as in
%countries)
numbers=[3;4;6;7;8;9;10;11;12;13;14;15;16;17;18;19;20];
%set in which row total exports/imports is stored
totline=2;

%set observation to split the sample (1:splitdate is in up),
%(splitdate+1:end is in after) 
splitdate=21;

%choose name of output file
savefile  = 'bilateral_trade';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

trb=[];
trbup=[];
trbafter=[];

load('tradefiles')

for i=1:size(countries,1)-1;
    iexp=[char(countries(i)),'exp'];
    iimp=[char(countries(i)),'imp'];
    aiexp=eval(iexp);
    aiimp=eval(iimp);
    aiexp=aiexp';
    aiimp=aiimp';
    aiexptot=aiexp(:,totline);
    aiimptot=aiimp(:,totline);
    for j=i+1:size(countries,1);
        jexp=[char(countries(j)),'exp'];
        jimp=[char(countries(j)),'imp'];
        ajexp=eval(jexp);
        ajimp=eval(jimp);
        ajexp=ajexp';
        ajimp=ajimp';
        ajexptot=ajexp(:,2);
        ajimptot=ajimp(:,2);
        
        %average exports from i to j
        expij=aiexp(1:end,numbers(j));
        expij(isnan(expij))=[];
        expij=mean(expij);
        %average imports of j from i
        impji=ajimp(1:end,numbers(i));
        impji(isnan(impji))=[];
        impji=mean(impji);
        %average them
        trade1=(expij+impji)/2;
        
        %average exports from j to i
        expji=ajexp(1:end,numbers(i));
        expji(isnan(expji))=[];
        expji=mean(expji);
        %average imports of j from i
        impij=aiimp(1:end,numbers(j));
        impij(isnan(impij))=[];
        impij=mean(impij);
        %average them
        trade2=(expji+impij)/2;
        
        %total exports and imports of country j of country i
        expi=aiexptot;
        expi(isnan(expi))=[];
        expi=mean(expi);
        impi=aiimptot;
        impi(isnan(impi))=[];
        impi=mean(impi);
        
        %total exports and imports of country j of country i
        expj=ajexptot;
        expj(isnan(expj))=[];
        expj=mean(expj);
        impj=ajimptot;
        impj(isnan(impj))=[];
        impj=mean(impj);
        
        %Compute bilateral trade coefficient
        trbil=(trade1+trade2)/(impi+expi+impj+expj);
        
        trb=[trb; trbil];
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Same thing for years up to 2000
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %average exports from i to j up to 2000
        expij=aiexp(1:splitdate,numbers(j));
        expij(isnan(expij))=[];
        expij=mean(expij);
        %average imports of j from i up to 2000
        impji=ajimp(1:splitdate,numbers(i));
        impji(isnan(impji))=[];
        impji=mean(impji);
        %average them
        trade1=(expij+impji)/2;
        
        %average exports from j to i
        expji=ajexp(1:splitdate,numbers(i));
        expji(isnan(expji))=[];
        expji=mean(expji);
        %average imports of j from i
        impij=aiimp(1:splitdate,numbers(j));
        impij(isnan(impij))=[];
        impij=mean(impij);
        %average them
        trade2=(expji+impij)/2;
        
        %total exports and imports of country j of country i
        expi=aiexptot(1:splitdate,:);
        expi(isnan(expi))=[];
        expi=mean(expi);
        impi=aiimptot(1:splitdate,:);
        impi(isnan(impi))=[];
        impi=mean(impi);
        
        %total exports and imports of country j of country i
        expj=ajexptot(1:splitdate,:);
        expj(isnan(expj))=[];
        expj=mean(expj);
        impj=ajimptot(1:splitdate,:);
        impj(isnan(impj))=[];
        impj=mean(impj);
        
        %Compute bilateral trade coefficient
        trbilup=(trade1+trade2)/(impi+expi+impj+expj);
        
        trbup=[trbup; trbilup];
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Same thing for years after to 2000
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %average exports from i to j after to 2000
        expij=aiexp(splitdate+1:end,numbers(j));
        expij(isnan(expij))=[];
        expij=mean(expij);
        %average imports of j from i after to 2000
        impji=ajimp(splitdate+1:end,numbers(i));
        impji(isnan(impji))=[];
        impji=mean(impji);
        %average them
        trade1=(expij+impji)/2;
        
        %average exports from j to i
        expji=ajexp(splitdate+1:end,numbers(i));
        expji(isnan(expji))=[];
        expji=mean(expji);
        %average imports of j from i
        impij=aiimp(splitdate+1:end,numbers(j));
        impij(isnan(impij))=[];
        impij=mean(impij);
        %average them
        trade2=(expji+impij)/2;
        
        %total exports and imports of country j of country i
        expi=aiexptot(splitdate+1:end,:);
        expi(isnan(expi))=[];
        expi=mean(expi);
        impi=aiimptot(splitdate+0:end,:);
        impi(isnan(impi))=[];
        impi=mean(impi);
        
        %total exports and imports of country j of country i
        expj=ajexptot(splitdate+1:end,:);
        expj(isnan(expj))=[];
        expj=mean(expj);
        impj=ajimptot(splitdate+1:end,:);
        impj(isnan(impj))=[];
        impj=mean(impj);
        
        %Compute bilateral trade coefficient
        trbilafter=(trade1+trade2)/(impi+expi+impj+expj);
        
        trbafter=[trbafter; trbilafter];
        
    end;
end;

labels=[];
for i=1:size(countries,1)-1;
    for j=i+1:size(countries,1);
        label=[countries(i) countries(j)];
        labels=[labels; label];
    end;
end;

save(savefile, 'trb','trbup','trbafter','countries', 'labels');